==============================================================
2018-02-15 Use of OpenStack CI Resources for External Projects
==============================================================

Many organizations generously donate cloud computing resources to the
OpenStack project for use by its testing and automation system so that
we can maintain and improve the quality of our software.  We are
stewards of these resources and strive to use them wisely and
responsibly.

Toward our goal of improving interaction with other communities, we
support the use of some of those resources toward testing OpenStack
software with other software projects which are developed outside of
the OpenStack community.

In order to ensure that cloud computing resources donated to the
OpenStack project are used responsibly, use of resources for this
purpose are permitted only for integration testing with open-source
projects which are direct dependencies or direct downstream consumers
of official OpenStack projects.
